@@ -2,6 +2,7 @@ import logging
 import sys
 import warnings
 import json
+import sqlalchemy
 from sqlalchemy.engine import create_engine
 from sqlalchemy import MetaData
 from sqlalchemy import Table
@@ -576,6 +577,7 @@ class FieldsConverter:
         self.engine_to = create_engine(uri_sql_alchemy_to, connect_args=connect_args)
         self.conn_to = self.engine_to.connect()
         self.log("connecting to {} successfull".format(self.to_db))
+        self.init_meta(tables=self.tables)
 
     def init_meta(self, tables=None):
         """
@@ -583,6 +585,7 @@ class FieldsConverter:
         :param tables:
         :return:
         """
+
         if "schema" in self.cred_from:
             self.schema_from = self.cred_from["schema"]
             self.meta_from = MetaData(bind=self.engine_from, schema=self.schema_from)
@@ -597,8 +600,21 @@ class FieldsConverter:
 
         tables = tables or self.tables
         if len(tables) > 0:
-            self.meta_from.reflect(only=tables)
-            self.meta_to.reflect(only=tables)
+            try:
+                self.meta_from.reflect(only=tables)
+            except sqlalchemy.exc.InvalidRequestError:
+                raise sqlalchemy.exc.InvalidRequestError(
+                    "One or more file didn't find in database {}. Critical exception"
+                )
+            try:
+                self.meta_to.reflect(only=tables)
+            except sqlalchemy.exc.InvalidRequestError:
+                self.log(
+                    "One or more file didn't find in database {}. Load table later".format(
+                        self.to_db
+                    )
+                )
+                self.meta_to = None
         else:
             self.meta_from.reflect()
             self.meta_to.reflect()
@@ -654,8 +670,8 @@ class FieldsConverter:
             if sort_part is not None:
                 add_part = generate_sort_part_vertica(sort_part, date_field=date_field)
                 if (
-                    date_field != ""
-                    and fields[date_field].lower().find("not null") == -1
+                        date_field != ""
+                        and fields[date_field].lower().find("not null") == -1
                 ):
                     fields[date_field] += " not null"
         elif self.to_db == "exasol":
@@ -748,4 +764,6 @@ class FieldsConverter:
                 )
                 f.write(sql)
                 f.close()
+        if to_create:
+            self.init_meta()
         return result_list
